pub struct TaskSnapshot {
pub id: u64,
pub session_id: String,
pub session_title: String,
pub model: String,
pub backend: String,
pub status: String,
pub buffer_chars: usize,
}Fields
id: u64session_id: Stringsession_title: Stringmodel: Stringbackend: Stringstatus: String“tool” while a tool runs, “streaming” otherwise. Tasks only live in the map while their loop is active, so there is no idle state.
buffer_chars: usizeTrait Implementations
Sourceimpl Clone for TaskSnapshot
impl Clone for TaskSnapshot
Sourcefn clone(&self) -> TaskSnapshot
fn clone(&self) -> TaskSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TaskSnapshot
impl Debug for TaskSnapshot
Sourceimpl<'de> Deserialize<'de> for TaskSnapshot
impl<'de> Deserialize<'de> for TaskSnapshot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more