Module v2_generated

Module v2_generated 

Structs

RecordV2
RecordV2Args
RecordV2Builder

Enums

RecordV2Offset

Functions

finish_record_v2_buffer
finish_size_prefixed_record_v2_buffer
root_as_record_v2
Verifies that a buffer of bytes contains a RecordV2 and returns it. Note that verification is still experimental and may not catch every error, or be maximally performant. For the previous, unchecked, behavior use root_as_record_v2_unchecked.
root_as_record_v2_unchecked
Assumes, without verification, that a buffer of bytes contains a RecordV2 and returns it.
root_as_record_v2_with_opts
Verifies, with the given options, that a buffer of bytes contains a RecordV2 and returns it. Note that verification is still experimental and may not catch every error, or be maximally performant. For the previous, unchecked, behavior use root_as_record_v2_unchecked.
size_prefixed_root_as_record_v2
Verifies that a buffer of bytes contains a size prefixed RecordV2 and returns it. Note that verification is still experimental and may not catch every error, or be maximally performant. For the previous, unchecked, behavior use size_prefixed_root_as_record_v2_unchecked.
size_prefixed_root_as_record_v2_unchecked
Assumes, without verification, that a buffer of bytes contains a size prefixed RecordV2 and returns it.
size_prefixed_root_as_record_v2_with_opts
Verifies, with the given verifier options, that a buffer of bytes contains a size prefixed RecordV2 and returns it. Note that verification is still experimental and may not catch every error, or be maximally performant. For the previous, unchecked, behavior use root_as_record_v2_unchecked.